@@ -55,6 +55,12 @@ print.summary.simsum <- function(x, digits = 4, mcse = TRUE, ...) {
   ### Order data.frame with results
   x$summ <- .order(data = x$summ, by = c("Performance Measure", x$methodvar, x$by))
 
+  ### If length(methodvar) > 1 then process multiple columns into one...
+  if (length(x$methodvar) > 1) {
+    x$summ <- .compact_method_columns(data = x$summ, methodvar = x$methodvar)$data
+    x$methodvar <- ":methodvar"
+  }
+
   ### If methodvar, put them side by side
   if (!is.null(x$methodvar)) {
     x$summ <- .bind_methods(data = x$summ, by = x$by, methodvar = x$methodvar)
